geowatch.tasks.invariants.segmentation\_model module
====================================================

.. automodule:: geowatch.tasks.invariants.segmentation_model
   :members:
   :undoc-members:
   :show-inheritance:
